package yrpg.application.crmvisit.plugin.form;

import kd.bos.context.RequestContext;
import kd.bos.dataentity.entity.DynamicObject;
import kd.bos.dataentity.entity.DynamicObjectCollection;
import kd.bos.form.CloseCallBack;
import kd.bos.form.MobileFormShowParameter;
import kd.bos.form.ShowType;
import kd.bos.form.control.Control;
import kd.bos.form.control.Image;
import kd.bos.form.control.Label;
import kd.bos.form.events.BeforeCreateListDataProviderArgs;
import kd.bos.form.plugin.AbstractMobFormPlugin;
import kd.bos.list.BillList;
import kd.bos.list.events.CreateListDataProviderListener;
import kd.bos.mvc.list.ListDataProvider;
import kd.bos.servicehelper.user.UserServiceHelper;
import kd.bos.servicehelper.workflow.WorkflowServiceHelper;
import kd.sdk.plugin.Plugin;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.EventObject;
import java.util.List;
import java.util.Map;
import java.util.Optional;

/**
 * 单据界面插件(移动端)
 * 科研助手 - 首页：yrpg_firstpage
 */
public class FirstPageMobFormPlugin extends AbstractMobFormPlugin implements CreateListDataProviderListener, Plugin {
    @Override
    public void beforeBindData(EventObject e) {
        super.beforeBindData(e);
    }

    @Override
    public void afterCreateNewData(EventObject e) {
        super.afterCreateNewData(e);
        Long userId = RequestContext.get().getCurrUserId();
        Image image = this.getView().getControl("yrpg_head");
        String userImageUrl = getUserImageFullPath(userId);
        image.setUrl(userImageUrl);
        Label label = this.getView().getControl("yrpg_name");
        String userName = RequestContext.get().getUserName();
        label.setText("你好，" + userName);
    }

    private static String getUserImageFullPath(Long userId) {
        List<Long> id = new ArrayList(1);
        id.add(userId);
        Map<Long, String> userAvatarPath = UserServiceHelper.getUserAvatarPath(id, true);
        return userAvatarPath.size() > 0 ? (String) userAvatarPath.get(userId) : null;
    }

    @Override
    public void initialize() {
        super.initialize();
        BillList billList = getControl("yrpg_billlistap");
        billList.addCreateListDataProviderListener(this);
    }

    @Override
    public void createListDataProvider(BeforeCreateListDataProviderArgs arg0) {
        arg0.setListDataProvider(new ListDataProvider() {
            public DynamicObjectCollection getData(int start, int limit) {
                //获取空白数据行，主要为了取列表的数据显示格式和需要赋值的字段标识
                DynamicObjectCollection allRows = super.getData(start, limit);
                //获取待办任务
                String userId = String.valueOf(RequestContext.get().getCurrUserId());
                DynamicObjectCollection resultList = WorkflowServiceHelper.getToHandleTasksByUserId(0, 3, userId);
                //对结果集进行处理，添加到allRows中
                if (Optional.ofNullable(resultList).isPresent()) {
                    resultList.forEach(entity -> {
                        DynamicObject dynamicObject = allRows.addNew();
                        dynamicObject.set("entryentity.yrpg_processtheme", entity.get("ENTITYNAME"));
                        dynamicObject.set("entryentity.yrpg_promoter", entity.get("STARTNAME"));
                        dynamicObject.set("entryentity.yrpg_initiationtime", entity.get("CREATEDATE"));

                    });
                }
                //返回结果
                return allRows;
            }
        });
    }

    @Override
    public void registerListener(EventObject e) {
        super.registerListener(e);
        this.addClickListeners("yrpg_seemore", "yrpg_yx", "yrpg_yxtp", "yrpg_yxbf");

    }

    @Override
    public void click(EventObject evt) {
        super.click(evt);
        Control source = (Control) evt.getSource();
        String key = source.getKey();
        //院线拜访
        List<String> yX = Arrays.asList(new String[]{"yrpg_yx", "yrpg_yxtp", "yrpg_yxbf"});
        if (key.equals("yrpg_seemore")) {
            MobileFormShowParameter showParameter = new MobileFormShowParameter();
            showParameter.setFormId("yrpg_processcenter");
            showParameter.setCloseCallBack(new CloseCallBack(this, "yrpg_processcenter"));
            showParameter.getOpenStyle().setShowType(ShowType.Floating);
            this.getView().showForm(showParameter);
        } else if (yX.contains(key)) {
            MobileFormShowParameter showParameter = new MobileFormShowParameter();
            showParameter.setFormId("yrpg_visit_list");
            showParameter.getOpenStyle().setShowType(ShowType.Floating);
            this.getView().showForm(showParameter);
        }
    }
}